"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Asset {
    constructor(data, uuid) {
        this.data = data;
        this.uuid = uuid || this.generateGuid();
    }
    /**
     * @returns {Promise<string>} The Asset's content in Base64
     */
    toString() {
        return new Promise(resolve => {
            try {
                const reader = new FileReader();
                reader.onload = event => resolve(event.target.result);
                reader.readAsDataURL(this.data);
            }
            catch (e) {
                resolve('');
            }
        });
    }
    /**
     * @returns {Promise<any>} A version of the Asset that the XML generator can parse
     */
    async toXmlObject() {
        const b64 = await this.toString();
        return {
            $: {
                uuid: this.uuid
            },
            _: b64
        };
    }
    generateGuid() {
        function s4() {
            return Math.floor((1 + Math.random()) * 0x10000).toString(16).substring(1);
        }
        return s4() + s4() + '-' + s4() + '-' + s4() + '-' + s4() + '-' + s4() + s4() + s4();
    }
}
exports.default = Asset;
//# sourceMappingURL=Asset.js.map