import { Asset, FlatNotepad, Note, Section } from './';
import { MarkdownNote } from './Note';
import { NotepadShell } from "./interfaces";
import { EncryptionMethod } from './crypto';
export declare type NotepadOptions = {
    lastModified?: Date;
    sections?: Section[];
    notepadAssets?: string[];
    assets?: Asset[];
    crypto?: EncryptionMethod;
};
/**
 * This class is identical in structure to the old Notepad class from the original parser.
 * This represents the notepad as a tree. If you're looking for a flatter structure you can use {@link FlatNotepad}.
 *
 * Something to remember is that all operations on this class like addSection, will return a <strong>new</strong>
 * object of this class, and not modify the existing one.
 */
export default class Notepad implements NotepadShell {
    readonly title: string;
    readonly lastModified: string;
    readonly sections: Section[];
    readonly notepadAssets: string[];
    readonly assets: Asset[];
    readonly crypto?: EncryptionMethod;
    constructor(title: string, opts?: NotepadOptions);
    addSection(section: Section): Notepad;
    addAsset(asset: Asset): Notepad;
    /**
     * This updates the lastModified date on the notepad. This date is used for syncing so it's important
     * to call this method whenever a change is made that will need to be synced.
     * @param {Date} lastModified
     * @returns {Notepad}
     */
    modified(lastModified?: Date): Notepad;
    /**
     * @param {string} query Can either be a title-search or a hashtag-search
     * @returns {Note[]}
     */
    search(query: string): Note[];
    toJson(passkey?: string): Promise<string>;
    toXml(): Promise<string>;
    flatten(): FlatNotepad;
    toMarkdown(assets: Asset[]): Promise<MarkdownNote[]>;
    clone(opts?: Partial<NotepadOptions>, title?: string): Notepad;
    private toXmlObject;
}
