"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const NPXObject_1 = require("./NPXObject");
class Section extends NPXObject_1.NPXObject {
    constructor(title, sections = [], notes = [], internalRef, parent) {
        super(title, internalRef, parent);
        this.title = title;
        this.sections = sections;
        this.notes = notes;
    }
    addSection(section) {
        const sectionClone = section.clone();
        const parent = this.clone({
            sections: [
                ...this.sections,
                sectionClone
            ]
        });
        sectionClone.parent = parent;
        return parent;
    }
    addNote(note) {
        const noteClone = note.clone();
        const parent = this.clone({
            notes: [
                ...this.notes,
                noteClone
            ]
        });
        noteClone.parent = parent;
        return parent;
    }
    search(query) {
        const subSectionNotes = this.sections
            .map(s => s.search(query))
            .reduce((acc, val) => acc.concat(val), []);
        return [
            ...this.notes.filter(n => n.search(query).length > 0),
            ...subSectionNotes
        ];
    }
    toXmlObject() {
        return {
            section: {
                $: {
                    title: this.title
                },
                section: this.sections.map(s => s.toXmlObject().section),
                note: this.notes.map(n => n.toXmlObject().note)
            }
        };
    }
    async toMarkdown(assets) {
        const subSectionNotes = (await Promise.all(this.sections.map(s => s.toMarkdown(assets)))).reduce((acc, val) => acc.concat(val), []);
        return [
            ...await Promise.all([
                ...this.notes.map(n => n.toMarkdown(assets)),
            ]),
            ...subSectionNotes
        ];
    }
    clone(opts = {}) {
        return new Section(opts.title || this.title, [
            ...(opts.sections || this.sections),
        ], [
            ...(opts.notes || this.notes),
        ], opts.internalRef || this.internalRef, opts.parent || this.parent);
    }
}
exports.default = Section;
//# sourceMappingURL=Section.js.map