import { FlatNotepad, Notepad } from './index';
export declare namespace Translators {
    namespace Json {
        /**
         * @param {string | object} json A {@link Notepad} object in JSON format or as a plain object
         * @param {string | undefined} passkey The passkey to decrypt the notepad if it's encrypted.
         * @returns {Notepad}
         */
        function toNotepadFromNotepad(json: string | object, passkey?: string): Promise<Notepad>;
        /**
         * @param {string | object} json A {@link Notepad} object in JSON format or as a plain object
         * @param {string | undefined} passkey The passkey to decrypt the notepad if it's encrypted.
         * @returns {FlatNotepad}
         */
        function toFlatNotepadFromNotepad(json: string | object, passkey?: string): Promise<FlatNotepad>;
        /**
         * @param {string} json A Jupyter notebook (.ipynb)
         * @returns {string} A Markdown translation of that notebook
         */
        function toMarkdownFromJupyter(json: string): string;
    }
    namespace Xml {
        /**
         * @param {string} xml The NPX file's contents as a string
         * @returns {Promise<Notepad>}
         */
        function toNotepadFromNpx(xml: string): Promise<Notepad>;
        /**
         * @param {string} xml The exported Evernote notepad's XML as a string
         * @returns {Promise<Notepad>}
         */
        function toNotepadFromEnex(xml: string): Promise<Notepad>;
    }
    namespace Markdown {
        /**
         * @param {Array<MarkdownImport>} markdown A list of all the markdown to be imported into notes
         */
        function toNotepadFromMarkdown(markdown: MarkdownImport[]): Notepad;
        type MarkdownImport = {
            title: string;
            content: string;
        };
    }
}
